<?php

/**
 * @file
 * File for display suite related functions.
 */

function prv_extras_search_api_excerpt($field) {
  $excerpt = '';
  $settings = isset($field['formatter_settings']) ? $field['formatter_settings'] : array();
  $settings += $field['properties']['default'];
  $id = entity_extract_ids($field['entity_type'], $field['entity']);
  $entity_properties = & drupal_static(PRV_EXTRAS_ENTITY_PROPERTIES);

  // Does an excerpt exist for this result
  // Version for search_api < 1.2
  if (isset($id[0])
    && isset($entity_properties[$field['entity_type']][$id[0]]['search_api_excerpt'])
  ) {
    $excerpt = $entity_properties[$field['entity_type']][$id[0]]['search_api_excerpt'];
  }
  // Version for search_api >= 1.2 with the new schema.xml
  elseif (isset($id[0])
    && is_array($entity_properties[$field['entity_type']])
  ) {
    $excerpt = _prv_extras_find_excerpt_in_result($id[0], $entity_properties[$field['entity_type']]);
  }

  // Has the excerpt no <strong> tags, the alternate field text (spell) from solr is returned
  // In this case, the search module excerpt function is used to highlight and shorten the text
  if (strpos($excerpt, '<strong>') === FALSE && isset($entity_properties[$field['entity_type']]['keys'])) {
    // Include search module to use the function search_excerpt
    module_load_include('module', 'search');
    $keys = $entity_properties[$field['entity_type']]['keys'];
    $excerpt = search_excerpt($keys, $excerpt);
  }

  // Link?
  if ($settings['link']) {
    if (isset($field['entity']->uri['path'])) {
      $path = $field['entity']->uri['path'];
    }
    else {
      $uri_info = entity_uri($field['entity_type'], $field['entity']);
      $path = $uri_info['path'];
    }
    $excerpt = l($excerpt, $path, array('html' => TRUE));
  }

  return $excerpt;
}

/**
 * Get the excerpt form search api search result api.
 *
 * @param $id
 *   The entity id
 * @param array $result
 *   The
 * @return string
 */
function _prv_extras_find_excerpt_in_result($id, array $result) {
  $excerpt = '';

  foreach ($result as $element) {
    if ($element['search_api_item_id'] == $id) {

      $excerpt = $element['search_api_excerpt'];
      break;
    }
  }

  return $excerpt;
}
